@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdedit_audio.cpp,v 1.4 2007/02/14 21:48:41 fredg Exp $
+//      $Id: rdedit_audio.cpp,v 1.5 2007/03/12 11:57:01 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -579,8 +579,8 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
 	       (int)RDEditAudio::HookStart);
   connect(edit_cue_button[RDEditAudio::HookStart],SIGNAL(clicked()),
 	  button_mapper,SLOT(map()));
-  edit_cursor_edit[RDEditAudio::HookStart]->hide();
-  edit_cue_button[RDEditAudio::HookStart]->hide();
+ // edit_cursor_edit[RDEditAudio::HookStart]->hide();
+ // edit_cue_button[RDEditAudio::HookStart]->hide();
 
 
   edit_cursor_edit[RDEditAudio::HookEnd]=
@@ -614,8 +614,8 @@ RDEditAudio::RDEditAudio(RDCart *cart,QString cut_name,RDCae *cae,RDUser *user,
     setMapping(edit_cue_button[RDEditAudio::HookEnd],(int)RDEditAudio::HookEnd);
   connect(edit_cue_button[RDEditAudio::HookEnd],SIGNAL(clicked()),
 	  button_mapper,SLOT(map()));
-  edit_cursor_edit[RDEditAudio::HookEnd]->hide();
-  edit_cue_button[RDEditAudio::HookEnd]->hide();
+  // edit_cursor_edit[RDEditAudio::HookEnd]->hide();
+  // edit_cue_button[RDEditAudio::HookEnd]->hide();
 
   //
   // AutoTrim Buttons
@@ -1048,11 +1048,13 @@ void RDEditAudio::playStartData()
 	break;
   }
   if(!is_playing) {
+    edit_cae->setPlayPortActive(edit_card,edit_port,edit_stream);
+    edit_cae->
+      setOutputVolume(edit_card,edit_stream,edit_port,0+edit_gain_control->value());
     edit_cae->play(edit_handle,(int)(1000.0*(double)
 			  ((edit_cursors[RDEditAudio::End]-
 			    edit_cursors[RDEditAudio::Start])*1152)/
 			  (double)edit_wave->getSamplesPerSec()),1000,0);
-    edit_cae->setPlayPortActive(edit_card,edit_port,edit_stream);
   }
   if(use_looping) {
     is_looping=true;
@@ -1114,8 +1116,10 @@ void RDEditAudio::playCursorData()
   played_cursor=edit_cursors[RDEditAudio::Play];
   pause_mode=false;
   if(!is_playing) {
-    edit_cae->play(edit_handle,length,1000,0);
     edit_cae->setPlayPortActive(edit_card,edit_port,edit_stream);
+    edit_cae->
+      setOutputVolume(edit_card,edit_stream,edit_port,0+edit_gain_control->value());
+    edit_cae->play(edit_handle,length,1000,0);
   }
   if(use_looping) {
     is_looping=true;
@@ -1639,8 +1643,8 @@ void RDEditAudio::paintEvent(QPaintEvent *e)
   //
   // Marker Control Area
   //
-//  p->drawRect(11,130+EDITAUDIO_WAVEFORM_HEIGHT,624,197);
-  p->drawRect(11,130+EDITAUDIO_WAVEFORM_HEIGHT,551,197);
+  p->drawRect(11,130+EDITAUDIO_WAVEFORM_HEIGHT,624,197);
+//  p->drawRect(11,130+EDITAUDIO_WAVEFORM_HEIGHT,551,197);
 
   p->end();
   delete p;
@@ -2202,10 +2206,14 @@ void RDEditAudio::LoopRegion(int cursor0,int cursor1)
   }
   if(cursor0==-1) {
     edit_cae->positionPlay(edit_handle,0);
+    edit_cae->
+      setOutputVolume(edit_card,edit_stream,edit_port,0+edit_gain_control->value());
     edit_cae->play(edit_handle,length,1000,0);
   }
   else {
     edit_cae->positionPlay(edit_handle,GetTime(cursor0*1152));
+    edit_cae->
+      setOutputVolume(edit_card,edit_stream,edit_port,0+edit_gain_control->value());
     edit_cae->play(edit_handle,length,1000,0);
   }
 }
