@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: edit_rdairplay.cpp,v 1.36 2007/02/16 18:58:31 fredg Exp $
+//      $Id: edit_rdairplay.cpp,v 1.38 2007/07/10 16:02:22 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -39,7 +39,7 @@
 
 #include <rd.h>
 #include <rdtextvalidator.h>
-#include <rdlist_logs.cpp>
+#include <rdlist_logs.h>
 
 #include <edit_rdairplay.h>
 #include <edit_now_next.h>
@@ -307,7 +307,7 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   // Now & Next Button
   //
   QPushButton *button=new QPushButton(this,"nownext_button");
-  button->setGeometry(815,540,180,50);
+  button->setGeometry(815,562,180,50);
   button->setFont(small_font);
   button->setText(tr("Configure Now && Next\nParameters"));
   connect(button,SIGNAL(clicked()),this,SLOT(nownextData()));
@@ -447,21 +447,31 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   label->setGeometry(830,276,150,15);
   label->setAlignment(AlignLeft|AlignVCenter);
 
+  //
+  // Label Template
+  //
+  air_label_template_edit=new QLineEdit(this,"air_label_template_edit");
+  air_label_template_edit->setGeometry(895,298,sizeHint().width()-910,20);
+  label=new QLabel(air_label_template_edit,tr("Label Template:"),
+		   this,"air_label_template_label");
+  label->setGeometry(790,298,100,20);
+  label->setAlignment(AlignRight|AlignVCenter);
+
   //
   // Miscellaneous Section
   //
   label=new QLabel(tr("Miscellaneous Settings"),this,"globals_label");
   label->setFont(big_font);
-  label->setGeometry(805,308,200,16);
+  label->setGeometry(805,330,200,16);
 
   //
   // Startup Mode
   //
   air_startup_box=new QComboBox(this,"air_startup_box");
-  air_startup_box->setGeometry(885,329,110,20);
+  air_startup_box->setGeometry(885,351,110,20);
   air_startup_label=new QLabel(air_startup_box,tr("Startup Mode:"),
 			     this,"air_startup_label");
-  air_startup_label->setGeometry(785,329,95,20);
+  air_startup_label->setGeometry(785,351,95,20);
   air_startup_label->setAlignment(AlignRight|AlignVCenter);
   air_startup_box->insertItem(tr("Previous"));
   air_startup_box->insertItem(tr("LiveAssist"));
@@ -472,47 +482,47 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   // Check Timesync
   //
   air_timesync_box=new QCheckBox(this,"air_timesync_box");
-  air_timesync_box->setGeometry(810,359,15,15);
+  air_timesync_box->setGeometry(810,381,15,15);
   air_timesync_label=new QLabel(air_timesync_box,tr("Check TimeSync"),
 			     this,"air_timesync_label");
-  air_timesync_label->setGeometry(830,359,100,15);
+  air_timesync_label->setGeometry(830,381,100,15);
   air_timesync_label->setAlignment(AlignLeft|AlignVCenter);
 
   //
   // Show Log Buttons
   //
   air_auxlog_box[0]=new QCheckBox(this,"air_auxlog1_box");
-  air_auxlog_box[0]->setGeometry(810,381,15,15);
+  air_auxlog_box[0]->setGeometry(810,403,15,15);
   label=new QLabel(air_auxlog_box[0],tr("Show Auxlog 1 Button"),
 		   this,"air_auxlog_label");
-  label->setGeometry(830,381,150,15);
+  label->setGeometry(830,403,150,15);
   label->setAlignment(AlignLeft|AlignVCenter);
 
   air_auxlog_box[1]=new QCheckBox(this,"air_auxlog2_box");
-  air_auxlog_box[1]->setGeometry(810,403,15,15);
+  air_auxlog_box[1]->setGeometry(810,425,15,15);
   label=new QLabel(air_auxlog_box[1],tr("Show Auxlog 2 Button"),
 		   this,"air_auxlog_label");
-  label->setGeometry(830,403,150,15);
+  label->setGeometry(830,425,150,15);
   label->setAlignment(AlignLeft|AlignVCenter);
 
   //
   // Clear Cart Filter
   //
   air_clearfilter_box=new QCheckBox(this,"air_clearfilter_box");
-  air_clearfilter_box->setGeometry(810,425,15,15);
+  air_clearfilter_box->setGeometry(810,447,15,15);
   label=new QLabel(air_clearfilter_box,tr("Clear Cart Search Filter"),
 		   this,"air_clearfilter_label");
-  label->setGeometry(830,425,150,15);
+  label->setGeometry(830,447,150,15);
   label->setAlignment(AlignLeft|AlignVCenter);
 
   //
   // Pause Enable Checkbox
   //
   air_pause_box=new QCheckBox(this,"air_pause_box");
-  air_pause_box->setGeometry(810,447,15,15);
+  air_pause_box->setGeometry(810,469,15,15);
   label=new QLabel(air_pause_box,tr("Enable Paused Events"),
 		   this,"air_pause_label");
-  label->setGeometry(830,447,150,15);
+  label->setGeometry(830,469,150,15);
   label->setAlignment(AlignLeft|AlignVCenter);
 
   //
@@ -520,7 +530,7 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   //
   air_bar_group=new QButtonGroup(1,Qt::Vertical,tr("Space Bar Action"),
 				 this,"air_bar_group");
-  air_bar_group->setGeometry(805,469,sizeHint().width()-815,55);
+  air_bar_group->setGeometry(805,491,sizeHint().width()-815,55);
   QRadioButton *rbutton=
     new QRadioButton(tr("None"),air_bar_group,"none_button");
   rbutton=new QRadioButton(tr("Start Next"),air_bar_group,"start_next_button");
@@ -530,18 +540,18 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   //
   label=new QLabel(tr("Start/Stop Settings"),this,"globals_label");
   label->setFont(big_font);
-  label->setGeometry(10,390,200,16);
+  label->setGeometry(10,411,200,16);
 
   //
   // Exit Password
   //
   air_exitpasswd_edit=new QLineEdit(this,"air_exitpasswd_edit");
-  air_exitpasswd_edit->setGeometry(100,412,sizeHint().width()-905,20);
+  air_exitpasswd_edit->setGeometry(100,434,sizeHint().width()-905,20);
   air_exitpasswd_edit->setEchoMode(QLineEdit::Password);
   air_exitpasswd_edit->setText("******");
   label=new QLabel(air_exitpasswd_edit,tr("Exit Password:"),
 		   this,"air_exitpasswd_label");
-  label->setGeometry(0,412,95,20);
+  label->setGeometry(0,434,95,20);
   label->setAlignment(AlignRight|AlignVCenter);
   connect(air_exitpasswd_edit,SIGNAL(textChanged(const QString &)),
 	  this,SLOT(exitPasswordChangedData(const QString &)));
@@ -550,7 +560,7 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   // Log Machine Selector
   //
   air_logmachine_box=new QComboBox(this,"air_logmachine_box");
-  air_logmachine_box->setGeometry(45,437,100,20);
+  air_logmachine_box->setGeometry(45,459,100,20);
   air_logmachine_box->insertItem(tr("Main Log"));
   for(unsigned i=1;i<RDAIRPLAY_LOG_QUANTITY;i++) {
     air_logmachine_box->insertItem(QString().sprintf("Aux %d Log",i));
@@ -562,13 +572,13 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   // Startup Mode
   //
   air_startmode_box=new QComboBox(this,"air_startmode_box");
-  air_startmode_box->setGeometry(100,462,240,20);
+  air_startmode_box->setGeometry(100,484,240,20);
   air_startmode_box->insertItem(tr("start with empty log"));
   air_startmode_box->insertItem(tr("load previous log"));
   air_startmode_box->insertItem(tr("load specified log"));
   label=new QLabel(air_exitpasswd_edit,tr("At Startup:"),
 		   this,"air_exitpasswd_label");
-  label->setGeometry(30,462,65,20);
+  label->setGeometry(30,484,65,20);
   label->setAlignment(AlignRight|AlignVCenter);
   connect(air_startmode_box,SIGNAL(activated(int)),
 	  this,SLOT(startModeChangedData(int)));
@@ -577,28 +587,28 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   // Auto Restart Checkbox
   //
   air_autorestart_box=new QCheckBox(this,"air_autorestart_box");
-  air_autorestart_box->setGeometry(105,487,15,15);
+  air_autorestart_box->setGeometry(105,509,15,15);
   air_autorestart_label=
     new QLabel(air_autorestart_box,tr("Restart Log After Unclean Shutdown"),
 	       this,"air_autorestart_label");
-  air_autorestart_label->setGeometry(125,487,250,15);
+  air_autorestart_label->setGeometry(125,509,250,15);
   air_autorestart_label->setAlignment(AlignLeft|AlignVCenter);
 
   //
   // Startup Log
   //
   air_startlog_edit=new QLineEdit(this,"air_startlog_edit");
-  air_startlog_edit->setGeometry(100,507,240,20);
+  air_startlog_edit->setGeometry(100,529,240,20);
   air_startlog_label=new QLabel(air_startlog_edit,tr("Log:"),
 		   this,"air_startlog_label");
-  air_startlog_label->setGeometry(30,507,65,20);
+  air_startlog_label->setGeometry(30,529,65,20);
   air_startlog_label->setAlignment(AlignRight|AlignVCenter);
 
   //
   //  Log Select Button
   //
   air_startlog_button=new QPushButton(this,"air_startlog_button");
-  air_startlog_button->setGeometry(350,505,50,24);
+  air_startlog_button->setGeometry(350,527,50,24);
   air_startlog_button->setFont(small_font);
   air_startlog_button->setText(tr("&Select"));
   connect(air_startlog_button,SIGNAL(clicked()),this,SLOT(selectData()));
@@ -658,6 +668,7 @@ EditRDAirPlay::EditRDAirPlay(RDStation *station,unsigned instance,
   air_bar_group->setButton((int)air_conf->barAction());
   air_flash_box->setChecked(air_conf->flashPanel());
   air_panel_pause_box->setChecked(air_conf->panelPauseEnabled());
+  air_label_template_edit->setText(air_conf->buttonLabelTemplate());
   air_pause_box->setChecked(air_conf->pauseEnabled());
   for(int i=0;i<10;i++) {
     air_start_rml_edit[i]->setText(air_conf->startRml(i));
@@ -809,6 +820,7 @@ void EditRDAirPlay::okData()
     setBarAction((RDAirPlayConf::BarAction)air_bar_group->selectedId());
   air_conf->setFlashPanel(air_flash_box->isChecked());
   air_conf->setPanelPauseEnabled(air_panel_pause_box->isChecked());
+  air_conf->setButtonLabelTemplate(air_label_template_edit->text());
   air_conf->setPauseEnabled(air_pause_box->isChecked());
   if(air_exitpasswd_changed) {
     air_conf->setExitPassword(air_exitpasswd_edit->text());
