@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: log_play.cpp,v 1.160 2007/02/19 19:48:46 fredg Exp $
+//      $Id: log_play.cpp,v 1.165 2007/06/30 10:03:16 stgabriel Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -46,6 +46,7 @@ LogPlay::LogPlay(RDCae *cae,int id,QSocketDevice *nn_sock,QString logname,
   play_trans_length=rdairplay_conf->transLength()+1;
   play_start_next=false;
   play_running=false;
+  play_next_line=0;
   play_post_time=QTime();
   play_start_time=QTime();
   play_post_offset=-1;
@@ -339,17 +340,17 @@ void LogPlay::load()
   // Remove All Idle Events
   //
   if((running=runningEvents(lines))==0) {
-    remove(0,size());
+    remove(0,size(),false);
   }
   else {
     if(lines[running-1]<(size()-1)) {
-      remove(lines[running-1]+1,size()-lines[running-1]-1);
+      remove(lines[running-1]+1,size()-lines[running-1]-1,false);
     }
     for(int i=running-2;i>0;i--) {
-      remove(lines[i-1]+1,lines[i]-lines[i-1]-1);
+      remove(lines[i-1]+1,lines[i]-lines[i-1]-1,false);
     }
     if(lines[0]!=0) {
-      remove(0,lines[0]);
+      remove(0,lines[0],false);
     }
   }
 
@@ -394,19 +395,19 @@ void LogPlay::load()
 }
 
 
-bool LogPlay::refresh()
-{
-  RDLogLine *s;
+bool LogPlay::refresh()            
+{                                  
+  RDLogLine *s;                    
   RDLogLine *d;
   int prev_line;
   int prev_id;
   int next_line=-1;
   int next_id=-1;
+  int current_id=-1;
+
+  int lines[TRANSPORT_QUANTITY];
+  int running;
 
-  //
-  // Get the Next Event
-  //
-  next_id=nextEvent()->id();
 
   //
   // Load the Updated Log
@@ -416,6 +417,27 @@ bool LogPlay::refresh()
   e->load();
   play_modified_datetime=play_log->modifiedDatetime();
 
+
+  //
+  // Get the Next Event
+  //
+  if(nextEvent()!=NULL) {   //End of the log?
+    next_id=nextEvent()->id();
+    }
+
+  //
+  // Get Running Events
+  //
+  running=runningEvents(lines);
+  for(int i=0;i<running;i++) {
+    if(lines[i]==play_next_line-1) {
+      current_id=logLine(lines[i])->id();
+      }
+    }
+  if(running>0 && next_id==-1) {                  //Last Event of Log Running?
+    current_id=logLine(lines[running-1])->id();
+    }
+
   //
   // Pass 1: Finished or Active Events
   //
@@ -434,7 +456,7 @@ bool LogPlay::refresh()
   //
   for(int i=size()-1;i>=0;i--) {
     if(logLine(i)->pass()==0) {
-      remove(i,1);
+      remove(i,1,false,true);
     }
   }
 
@@ -445,11 +467,11 @@ bool LogPlay::refresh()
     s=e->logLine(i);
     if(s->pass()==0) {
       if((prev_line=(i-1))<0) {  // First Event
-	insert(0,s);
+	insert(0,s,false,true);
       }
       else {
-	prev_id=e->logLine(prev_line)->id();
-	insert(lineById(prev_id)+1,s);
+	prev_id=e->logLine(prev_line)->id();   
+	insert(lineById(prev_id)+1,s,false,true);   
       }
     }
     else {
@@ -462,18 +484,25 @@ bool LogPlay::refresh()
   //
   for(int i=size()-1;i>=0;i--) {
     d=logLine(i);
-    if((d->status()!=RDLogLine::Scheduled)&&(d->pass()!=2)) {
-      remove(i,1);
+    if((d->status()==RDLogLine::Finished)&&(d->pass()!=2)) {
+      remove(i,1,false,true);
     }
   }
 
   //
   // Restore Next Event
   //
-  if((next_line=lineById(next_id))>=0) {
-    makeNext(next_line);
-  }
-
+  if(current_id!=-1 && e->loglineById(current_id)!=NULL) {    //Make Next after currently playing cart
+    if((next_line=lineById(current_id))>=0) {    
+      makeNext(next_line+1,false);              
+      }
+    }
+  else {
+    if((next_line=lineById(next_id))>=0) {     
+      makeNext(next_line,false);               
+      }
+    } 
+  
   //
   // Clean Up
   //
@@ -481,7 +510,11 @@ bool LogPlay::refresh()
   for(int i=0;i<size();i++) {
     logLine(i)->clearPass();
   }
-  RefreshEvents(0,size(),true);
+  RefreshEvents(0,size());
+  UpdateStartTimes(next_line);
+  UpdatePostPoint(play_line_counter);
+  SetTransTimer();
+  emit transportChanged();
   emit reloaded();
   if(!play_refreshable) {
     play_refreshable=false;
@@ -582,7 +615,7 @@ void LogPlay::insert(int line,int cartnum,RDLogLine::TransType next_type,
 }
 
 
-void LogPlay::insert(int line,RDLogLine *l)
+void LogPlay::insert(int line,RDLogLine *l,bool update,bool preserv_custom_transition)
 {
   RDLogLine *logline;
   int lines[TRANSPORT_QUANTITY];
@@ -608,13 +641,13 @@ void LogPlay::insert(int line,RDLogLine *l)
   if(play_macro_deck->line()>=0) {
     play_macro_deck->setLine(play_macro_deck->line()+1);
   }
-  RDLogEvent::insert(line,1);
+  RDLogEvent::insert(line,1,preserv_custom_transition);
   if((logline=logLine(line))==NULL) {
     RDLogEvent::remove(line,1);
     return;
   }
   *logline=*l;
-  if(nextLine()>line) {
+  if(nextLine()>line && update) {
     makeNext(nextLine()+1);
   }
   if(nextLine()<0) {
@@ -622,18 +655,20 @@ void LogPlay::insert(int line,RDLogLine *l)
   }
   logline->
     setTimescalingActive(play_timescaling_available&&logline->enforceLength());
-  UpdateStartTimes(line);
-  emit inserted(line);
-  UpdatePostPoint(play_line_counter);
-  if(mod_line>=0) {
-    emit modified(mod_line);
-  }
-  emit transportChanged();
-  SetTransTimer();
+  if(update) {
+    UpdateStartTimes(line);
+    emit inserted(line);
+    UpdatePostPoint(play_line_counter);
+    if(mod_line>=0) {
+      emit modified(mod_line);
+    }
+    emit transportChanged();
+    SetTransTimer();
+    }
 }
 
 
-void LogPlay::remove(int line,int num_lines)
+void LogPlay::remove(int line,int num_lines,bool update,bool preserv_custom_transition)
 {
   RDPlayDeck *playdeck;
   RDLogLine *logline;
@@ -658,7 +693,9 @@ void LogPlay::remove(int line,int num_lines)
 
   int lines[TRANSPORT_QUANTITY];
 
-  emit removed(line,num_lines,false);
+  if(update) {
+    emit removed(line,num_lines,false);
+    }
   int running=runningEvents(lines);
   for(int i=0;i<running;i++) {
     if((logline=logLine(lines[i]))!=NULL) {
@@ -672,20 +709,22 @@ void LogPlay::remove(int line,int num_lines)
     play_macro_deck->setLine(play_macro_deck->line()-num_lines);
   }
 
-  RDLogEvent::remove(line,num_lines);
-  if(nextLine()>line) {
-    makeNext(nextLine()-num_lines);
-  }
-  UpdateStartTimes(line);
-  UpdatePostPoint(line-num_lines);
-  if(size()==0) {
-    emit reloaded();
-  }
-  if(mod_line>=0) {
-    emit modified(mod_line);
-  }
-  emit transportChanged();
-  SetTransTimer();
+  RDLogEvent::remove(line,num_lines,preserv_custom_transition);
+  if(update) {
+    if(nextLine()>line) {
+      makeNext(nextLine()-num_lines);
+    }
+    UpdateStartTimes(line);
+    UpdatePostPoint(line-num_lines);
+    if(size()==0) {
+      emit reloaded();
+    }
+    if(mod_line>=0) {
+      emit modified(mod_line);
+    }
+    emit transportChanged();
+    SetTransTimer();
+    }
 }
 
 
@@ -1165,7 +1204,8 @@ void LogPlay::segueStartData(int id)
     }
     StartEvent(play_next_line,RDLogLine::Segue,
 	       logline->segueTail(next_logline->transType()),
-	       RDLogLine::StartSegue);
+	       RDLogLine::StartSegue,-1,
+  	       logline->segueTail(next_logline->transType()));
   }
 }
 
@@ -1317,7 +1357,7 @@ void LogPlay::rescanEventsData()
 
 
 bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
-			 int trans_length,RDLogLine::StartSource src,int mport)
+			 int trans_length,RDLogLine::StartSource src,int mport,int duck_length)
 {
   int running;
   int lines[TRANSPORT_QUANTITY];
@@ -1326,7 +1366,6 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
   RDPlayDeck *playdeck;
   int card;
   int port;
-  int start_line=0;
   int aport;
   bool was_paused=false;
 
@@ -1458,7 +1497,7 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
 	  LogLine(QString().sprintf("*** position out of bounds: Line: %d  Cart: %d  Pos: %d ***",line,logline->cartNumber(),logline->playPosition()));
 	  logline->setPlayPosition(0);
 	}
-	playdeck->play(logline->playPosition());
+	playdeck->play(logline->playPosition(),-1,-1,duck_length);
 	if(logline->status()==RDLogLine::RDLogLine::Paused) {
 	  logline->
 	    setStartTime(RDLogLine::Actual,playdeck->startTime());
@@ -1474,8 +1513,9 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
 	    exec(logline->resolveWildcards(play_start_rml[aport]));
 	}
 	LogLine(QString().sprintf(
-		  "started audio cart: Line: %d  Cart: %u  Pos: %d  Card: %d  Stream: %d  Port: %d",
+		  "started audio cart: Line: %d  Cart: %u  Cut: %u Pos: %d  Card: %d  Stream: %d  Port: %d",
 		  line,logline->cartNumber(),
+		  playdeck->cut()->cutNumber(),
 		  logline->playPosition(),
 		  playdeck->card(),
 		  playdeck->stream(),
@@ -1584,17 +1624,10 @@ bool LogPlay::StartEvent(int line,RDLogLine::TransType trans_type,
 	  }
 	}
 	if(GetTransType(logline->markerLabel(),0)!=RDLogLine::Stop) {
-	  running=runningEvents(lines);
-	  for(int i=0;i<running;i++) {
-	    if(logLine(lines[i])->status()==RDLogLine::Finishing) {
-	      start_line++;
-	    }
-	  }
 	  play_macro_deck->
-	    load(QString().sprintf("LL %d %s %d!",
+	    load(QString().sprintf("LL %d %s 0!",
 				   play_id+1,
-				   (const char *)logline->markerLabel(),
-				   start_line));
+				   (const char *)logline->markerLabel()));
 	}
 	else {
 	  play_macro_deck->
@@ -1684,9 +1717,11 @@ void LogPlay::CleanupEvent(int id)
   }
   playdeck=(RDPlayDeck *)logline->playDeck();
   LogLine(QString().
-  sprintf("finished event: Line: %d  Cart: %u  Card: %d  Stream: %d  Port: %d",
-		  line,logline->cartNumber(),playdeck->card(),
-		  playdeck->stream(),playdeck->port()));
+  sprintf("finished event: Line: %d  Cart: %u  Cut: %u Card: %d  Stream: %d  Port: %d",
+	  line,logline->cartNumber(),
+	  playdeck->cut()->cutNumber(),
+	  playdeck->card(),
+	  playdeck->stream(),playdeck->port()));
   RDLogLine *prev_logline;
   if((prev_logline=logLine(line-1))==NULL) {
   }
@@ -2180,32 +2215,34 @@ bool LogPlay::GetNextPlayable(int *line,bool skip_meta)
       emit modified(i);
     }
     else {
-      if(((logline->transType()==RDLogLine::Stop)||
-	  (play_op_mode==RDAirPlayConf::LiveAssist))&&((i-skipped)!=*line)) {
-	makeNext(i);
-	return false;
-      }
-      if((next_logline=logLine(i+1))!=NULL) {
-	next_type=next_logline->transType();
-      }
-      if((logline->setEvent(play_id,next_type,logline->timescalingActive())==
-	  RDLogLine::Ok)&&((logline->status()==RDLogLine::Scheduled)||
-			   (logline->status()==RDLogLine::Paused))&&
-	 (!logline->zombified())) {
-	emit modified(i);
-	*line=i;
-	return true;
-      }
-      else {
-//	logline->setStatus(RDLogLine::Finished);
-	logline->setStartTime(RDLogLine::Initial,QTime::currentTime());
-	if((logline->transType()==RDLogLine::Stop)&&(!logline->zombified())) {
+      if(logline->status()==RDLogLine::Scheduled || logline->status()==RDLogLine::Auditioning) {
+        if(((logline->transType()==RDLogLine::Stop)||
+	    (play_op_mode==RDAirPlayConf::LiveAssist))&&((i-skipped)!=*line)) {
+	  makeNext(i);
+	  return false;
+        }
+        if((next_logline=logLine(i+1))!=NULL) {
+	  next_type=next_logline->transType();
+        }
+        if((logline->setEvent(play_id,next_type,logline->timescalingActive())==
+	    RDLogLine::Ok)&&((logline->status()==RDLogLine::Scheduled)||
+	  		     (logline->status()==RDLogLine::Paused))&&
+	   (!logline->zombified())) {
 	  emit modified(i);
 	  *line=i;
 	  return true;
-	}
+        }
+        else {
+//	  logline->setStatus(RDLogLine::Finished);
+	  logline->setStartTime(RDLogLine::Initial,QTime::currentTime());
+	  if((logline->transType()==RDLogLine::Stop)&&(!logline->zombified())) {
+	    emit modified(i);
+	    *line=i;
+	    return true;
+	  }
+        }
+        emit modified(i);
       }
-      emit modified(i);
     }
   }
   return false;
@@ -2224,7 +2261,7 @@ void LogPlay::LogPlayEvent(RDLogLine *logline)
 
 void LogPlay::RefreshEvents(int line,int line_quan,bool force_update)
 {
-//  QTime st=QTime::currentTime();
+  //QTime st=QTime::currentTime();
 
   //
   // Check Event Status
