@@ -2,9 +2,9 @@
 //
 // The Rivendell Netcatcher Daemon
 //
-//   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcatchd.cpp,v 1.109 2007/03/01 13:52:09 fredg Exp $
+//      $Id: rdcatchd.cpp,v 1.111 2007/06/12 20:26:35 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -317,6 +317,8 @@ MainObject::MainObject(QObject *parent,const char *name)
   }
   delete q;
 
+  StartDropboxes();
+
   //
   // Time Engine
   //
@@ -386,6 +388,13 @@ MainObject::MainObject(QObject *parent,const char *name)
   q=new QSqlQuery(sql);
   delete q;
 
+  //
+  // Schedule Startup Cart
+  //
+  timer=new QTimer(this,"startup_cart_timer");
+  connect(timer,SIGNAL(timeout()),this,SLOT(startupCartData()));
+  timer->start(10000,true);
+
   LogLine("rdcatchd ready");
 }
 
@@ -1132,6 +1141,23 @@ void MainObject::updateXloadsData()
 }
 
 
+void MainObject::startupCartData()
+{
+  unsigned cartnum=catch_rdstation->startupCart();
+  if(cartnum>0) {
+    RDCart *cart=new RDCart(cartnum);
+    if(cart->exists()) {
+      ExecuteMacroCart(cart);
+      LogLine(QString().sprintf("ran startup cart %06u",cartnum));
+    }
+    else {
+      LogLine(QString().sprintf("startup cart %06u was invalid",cartnum));
+    }
+    delete cart;
+  }
+}
+
+
 bool MainObject::StartRecording(int event)
 {
   QString str;
@@ -1971,6 +1997,10 @@ void MainObject::DispatchCommand(int ch)
     LoadHeartbeat();
   }
 
+  if(!strcmp(args[ch][0],"RX")) {  // Restart Dropbox Instances
+    StartDropboxes();
+  }
+
   if(!strcmp(args[ch][0],"MN")) {  // Monitor State
     if(sscanf(args[ch][1],"%d",&chan)!=1) {
       return;
@@ -2913,6 +2943,69 @@ void MainObject::ResolveErrorWildcards(CatchEvent *event,
 }
 
 
+void MainObject::StartDropboxes()
+{
+  QString sql;
+  QSqlQuery *q;
+
+  //
+  // Kill Old Instances
+  //
+  system("killall rdimport");
+
+  //
+  // Launch Dropbox Configurations
+  //
+  sql=QString().sprintf("select GROUP_NAME,PATH,NORMALIZATION_LEVEL,\
+                         AUTOTRIM_LEVEL,TO_CART,USE_CARTCHUNK_ID,DELETE_CUTS,\
+                         METADATA_PATTERN,FIX_BROKEN_FORMATS,LOG_PATH \
+                         from DROPBOXES where STATION_NAME=\"%s\"",
+			(const char *)catch_config->stationName());
+  q=new QSqlQuery(sql);
+  while(q->next()) {
+    QString cmd="nice rdimport --log-mode --drop-box";
+    cmd+=
+      QString().sprintf(" --normalization-level=%d",q->value(2).toInt()/100);
+    cmd+=
+      QString().sprintf(" --autotrim-level=%d",q->value(3).toInt()/100);
+    if(q->value(4).toUInt()>0) {
+      cmd+=QString().sprintf(" --to-cart=%u",q->value(4).toUInt());
+    }
+    if(q->value(5).toString()=="Y") {
+      cmd+=" --use_cartchunk-cutid";
+    }
+    if(q->value(6).toString()=="Y") {
+      cmd+=" --delete-cuts";
+    }
+    if(!q->value(7).toString().isEmpty()) {
+      cmd+=QString().sprintf(" \"--metadata-pattern=%s\"",
+			     (const char *)q->value(7).toString());
+    }
+    if(q->value(8).toString()=="Y") {
+      cmd+=" --fix_broken_formats";
+    }
+    cmd+=QString().sprintf(" %s \"%s\"",(const char *)q->value(0).toString(),
+			   (const char *)q->value(1).toString());
+    if(!q->value(9).toString().isEmpty()) {
+      cmd+=QString().sprintf(" >> %s 2>> %s",
+			     (const char *)q->value(9).toString(),
+			     (const char *)q->value(9).toString());
+    }
+    else {
+      cmd+=" > /dev/null 2> /dev/null";
+    }
+    cmd+=" &";
+    LogLine(QString().sprintf("launching dropbox configuration: \"%s\"",
+			      (const char *)cmd));
+    if(fork()==0) {
+      system(cmd);
+      exit(0);
+    }
+  }
+  delete q;
+}
+
+
 int main(int argc,char *argv[])
 {
   QApplication a(argc,argv,false);
